@@ -1,5 +1,6 @@
 from django.conf.urls.defaults import patterns, url
 
 urlpatterns = patterns('tracking.views',
-    url(r'^dashboard/$', 'stats', name='tracking-dashboard'),
+    url(r'^$', 'dashboard', name='tracking-dashboard'),
+    url(r'^dashboard/$', 'stats'),
 )
